@@ -15,18 +15,15 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 from ... import lazy_import
+
 lazy_import.lazy_import(globals(), """
 from breezy.bzr.smart import request as _mod_request
 """)
 
 import breezy
+
+from ... import debug, errors, hooks, trace
 from . import message, protocol
-from ... import (
-    debug,
-    errors,
-    hooks,
-    trace,
-    )
 
 
 class _SmartClient:
