@@ -18,12 +18,9 @@
 """Tests for the _generate_text_key_index API."""
 
 
-from breezy.tests.scenarios import load_tests_apply_scenarios
 from breezy.bzr.tests.per_repository_vf import (
-    TestCaseWithRepository,
-    all_repository_vf_format_scenarios,
-    )
-
+    TestCaseWithRepository, all_repository_vf_format_scenarios)
+from breezy.tests.scenarios import load_tests_apply_scenarios
 
 load_tests = load_tests_apply_scenarios
 
