@@ -18,12 +18,11 @@ import codecs
 import os
 import time
 
-from ...tests import features, UnavailableFeature
 from ... import errors, filters, osutils, rules
 from ...controldir import ControlDir
+from ...tests import UnavailableFeature, features
 from ..conflicts import DuplicateEntry
 from ..transform import build_tree
-
 from . import TestCaseWithTransport
 
 
