@@ -16,25 +16,21 @@
 
 """Versioned text file storage api."""
 
-from copy import copy
-from io import BytesIO
 import itertools
 import os
 import struct
-from typing import Tuple, Any
+from copy import copy
+from io import BytesIO
+from typing import Any, Tuple
 from zlib import adler32
 
-
 from ..lazy_import import lazy_import
+
 lazy_import(globals(), """
 import fastbencode as bencode
 
 from breezy import (
-    annotate,
-    graph as _mod_graph,
-    osutils,
     multiparent,
-    tsort,
     revision,
     urlutils,
     )
@@ -43,17 +39,13 @@ from breezy.bzr import (
     knit,
     )
 """)
-from .. import (
-    errors,
-    transport as _mod_transport,
-    )
+from .. import errors
+from .. import graph as _mod_graph
+from .. import osutils
+from .. import transport as _mod_transport
 from ..registry import Registry
 from ..textmerge import TextMerge
-
-from . import (
-    index,
-    )
-
+from . import index
 
 adapter_registry = Registry[Tuple[str, str], Any]()
 adapter_registry.register_lazy(('knit-annotated-delta-gz', 'knit-delta-gz'),
@@ -88,7 +80,7 @@ class ExistingContent(errors.BzrError):
     _fmt = "The content being inserted is already present."
 
 
-class ContentFactory(object):
+class ContentFactory:
     """Abstract interface for insertion and retrieval from a VersionedFile.
 
     :ivar sha1: None, or the sha1 of the content fulltext.
@@ -303,7 +295,7 @@ def filter_absent(record_stream):
             yield record
 
 
-class _MPDiffGenerator(object):
+class _MPDiffGenerator:
     """Pull out the functionality for generating mp_diffs."""
 
     def __init__(self, vf, keys):
@@ -435,7 +427,7 @@ class _MPDiffGenerator(object):
         return [dpop(k) for k in self.ordered_keys]
 
 
-class VersionedFile(object):
+class VersionedFile:
     """Versioned text file storage.
 
     A versioned file manages versions of line-based text files,
@@ -788,7 +780,7 @@ class VersionedFile(object):
         return PlanWeaveMerge(plan, a_marker, b_marker).merge_lines()[0]
 
 
-class RecordingVersionedFilesDecorator(object):
+class RecordingVersionedFilesDecorator:
     """A minimal versioned files that records calls made on it.
 
     Only enough methods have been added to support tests using it to date.
@@ -877,16 +869,14 @@ class OrderingVersionedFilesDecorator(RecordingVersionedFilesDecorator):
             # Use a defined order by asking for the keys one-by-one from the
             # backing_vf
             for key in sorted(keys, key=sort_key):
-                for record in self._backing_vf.get_record_stream([key],
-                                                                 'unordered', include_delta_closure):
-                    yield record
+                yield from self._backing_vf.get_record_stream([key],
+                                                                 'unordered', include_delta_closure)
         else:
-            for record in self._backing_vf.get_record_stream(keys, sort_order,
-                                                             include_delta_closure):
-                yield record
+            yield from self._backing_vf.get_record_stream(keys, sort_order,
+                                                             include_delta_closure)
 
 
-class KeyMapper(object):
+class KeyMapper:
     """KeyMappers map between keys and underlying partitioned storage."""
 
     def map(self, key):
@@ -960,7 +950,7 @@ class HashPrefixMapper(URLEscapeMapper):
     def _map(self, key):
         """See KeyMapper.map()."""
         prefix = self._escape(key[0])
-        return "%02x/%s" % (adler32(prefix) & 0xff, prefix.decode('utf-8'))
+        return "{:02x}/{}".format(adler32(prefix) & 0xff, prefix.decode('utf-8'))
 
     def _escape(self, prefix):
         """No escaping needed here."""
@@ -1015,7 +1005,7 @@ def make_versioned_files_factory(versioned_file_factory, mapper):
     return factory
 
 
-class VersionedFiles(object):
+class VersionedFiles:
     """Storage for many versioned files.
 
     This object allows a single keyspace for accessing the history graph and
@@ -1292,7 +1282,8 @@ class VersionedFiles(object):
         return generator.compute_diffs()
 
     def get_annotator(self):
-        return annotate.Annotator(self)
+        from ..annotate import Annotator
+        return Annotator(self)
 
     missing_keys = index._missing_keys_from_parent_map
 
@@ -1720,8 +1711,7 @@ class PlanWeaveMerge(TextMerge):
         for state, line in self.plan:
             if state == 'unchanged':
                 # resync and flush queued conflicts changes if any
-                for struct in outstanding_struct():
-                    yield struct
+                yield from outstanding_struct()
                 lines_a = []
                 lines_b = []
                 ch_a = ch_b = False
@@ -1755,8 +1745,7 @@ class PlanWeaveMerge(TextMerge):
                 if state not in ('irrelevant', 'ghost-a', 'ghost-b',
                                  'killed-base'):
                     raise AssertionError(state)
-        for struct in outstanding_struct():
-            yield struct
+        yield from outstanding_struct()
 
     def base_from_plan(self):
         """Construct a BASE file from the plan text."""
@@ -1809,7 +1798,7 @@ class PlanWeaveMerge(TextMerge):
                     # It seems that having the line 2 times is better than
                     # having it omitted. (Easier to manually delete than notice
                     # it needs to be added.)
-                    raise AssertionError('Unknown state: %s' % (state,))
+                    raise AssertionError('Unknown state: {}'.format(state))
         return base_lines
 
 
@@ -1837,7 +1826,7 @@ class VirtualVersionedFiles(VersionedFiles):
         :param get_lines: Should return lines for specified key or None if
                           not available.
         """
-        super(VirtualVersionedFiles, self).__init__()
+        super().__init__()
         self._get_parent_map = get_parent_map
         self._get_lines = get_lines
 
@@ -1858,7 +1847,7 @@ class VirtualVersionedFiles(VersionedFiles):
     def get_parent_map(self, keys):
         """See VersionedFiles.get_parent_map."""
         parent_view = self._get_parent_map(k for (k,) in keys).items()
-        return dict(((k,), tuple((p,) for p in v)) for k, v in parent_view)
+        return {(k,): tuple((p,) for p in v) for k, v in parent_view}
 
     def get_sha1s(self, keys):
         """See VersionedFiles.get_sha1s."""
@@ -1893,7 +1882,7 @@ class VirtualVersionedFiles(VersionedFiles):
                 yield (l, key)
 
 
-class NoDupeAddLinesDecorator(object):
+class NoDupeAddLinesDecorator:
     """Decorator for a VersionedFiles that skips doing an add_lines if the key
     is already present.
     """
@@ -1944,7 +1933,7 @@ def network_bytes_to_kind_and_offset(network_bytes):
     return storage_kind, line_end + 1
 
 
-class NetworkRecordStream(object):
+class NetworkRecordStream:
     """A record_stream which reconstitures a serialised stream."""
 
     def __init__(self, bytes_iterator):
@@ -1972,9 +1961,8 @@ class NetworkRecordStream(object):
         """
         for bytes in self._bytes_iterator:
             storage_kind, line_end = network_bytes_to_kind_and_offset(bytes)
-            for record in self._kind_factory[storage_kind](
-                    storage_kind, bytes, line_end):
-                yield record
+            yield from self._kind_factory[storage_kind](
+                    storage_kind, bytes, line_end)
 
 
 def fulltext_network_to_record(kind, bytes, line_end):
@@ -2011,6 +1999,8 @@ def sort_groupcompress(parent_map):
 
     :return: A sorted-list of keys
     """
+    from ..tsort import topo_sort
+
     # gc-optimal ordering is approximately reverse topological,
     # properly grouped by file-id.
     per_prefix_map = {}
@@ -2027,11 +2017,11 @@ def sort_groupcompress(parent_map):
 
     present_keys = []
     for prefix in sorted(per_prefix_map):
-        present_keys.extend(reversed(tsort.topo_sort(per_prefix_map[prefix])))
+        present_keys.extend(reversed(topo_sort(per_prefix_map[prefix])))
     return present_keys
 
 
-class _KeyRefs(object):
+class _KeyRefs:
 
     def __init__(self, track_new_keys=False):
         # dict mapping 'key' to 'set of keys referring to that key'
