@@ -22,42 +22,19 @@ import os
 
 from dulwich.refs import SymrefLoop
 
-from .. import (
-    branch as _mod_branch,
-    errors as brz_errors,
-    trace,
-    osutils,
-    urlutils,
-    )
-from ..transport import (
-    do_catching_redirections,
-    get_transport_from_path,
-    FileExists,
-    NoSuchFile,
-    )
-
-from ..controldir import (
-    BranchReferenceLoop,
-    ControlDir,
-    ControlDirFormat,
-    format_registry,
-    RepositoryAcquisitionPolicy,
-    )
-
-from .mapping import (
-    decode_git_path,
-    encode_git_path,
-    )
-from .push import (
-    GitPushResult,
-    )
-from .transportgit import (
-    OBJECTDIR,
-    TransportObjectStore,
-    )
+from .. import branch as _mod_branch
+from .. import errors as brz_errors
+from .. import osutils, trace, urlutils
+from ..controldir import (BranchReferenceLoop, ControlDir, ControlDirFormat,
+                          RepositoryAcquisitionPolicy, format_registry)
+from ..transport import (FileExists, NoSuchFile, do_catching_redirections,
+                         get_transport_from_path)
+from .mapping import decode_git_path, encode_git_path
+from .push import GitPushResult
+from .transportgit import OBJECTDIR, TransportObjectStore
 
 
-class GitDirConfig(object):
+class GitDirConfig:
 
     def get_default_stack_on(self):
         return None
@@ -72,7 +49,7 @@ class GitControlDirFormat(ControlDirFormat):
     fixed_components = True
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def is_supported(self):
         return True
@@ -93,7 +70,7 @@ class UseExistingRepository(RepositoryAcquisitionPolicy):
         :param stack_on_pwd: If stack_on is relative, the location it is
             relative to.
         """
-        super(UseExistingRepository, self).__init__(
+        super().__init__(
             stack_on, stack_on_pwd, require_stacking)
         self._repository = repository
 
@@ -109,6 +86,10 @@ class UseExistingRepository(RepositoryAcquisitionPolicy):
 class GitDir(ControlDir):
     """An adapter to the '.git' dir used by git."""
 
+    @property
+    def control_transport(self):
+        return self.transport
+
     def is_supported(self):
         return True
 
@@ -156,8 +137,8 @@ class GitDir(ControlDir):
                accelerator_tree=None, hardlink=False, stacked=False,
                source_branch=None, create_tree_if_local=True):
         from ..repository import InterRepository
-        from ..transport.local import LocalTransport
         from ..transport import get_transport
+        from ..transport.local import LocalTransport
         target_transport = get_transport(url, possible_transports)
         target_transport.ensure_base()
         cloning_format = self.cloning_metadir()
@@ -242,8 +223,8 @@ class GitDir(ControlDir):
                            tag_selector=None):
         """See ControlDir.clone_on_transport."""
         from ..repository import InterRepository
-        from .mapping import default_mapping
         from ..transport.local import LocalTransport
+        from .mapping import default_mapping
         from .refs import is_peeled
         if no_tree:
             format = BareLocalGitControlDirFormat()
@@ -401,7 +382,7 @@ class LocalGitControlDirFormat(GitControlDirFormat):
 
     @classmethod
     def _known_formats(self):
-        return set([LocalGitControlDirFormat()])
+        return {LocalGitControlDirFormat()}
 
     @property
     def repository_format(self):
@@ -521,7 +502,7 @@ class LocalGitDir(GitDir):
         return LocalGitRepository
 
     def __repr__(self):
-        return "<%s at %r>" % (
+        return "<{} at {!r}>".format(
             self.__class__.__name__, self.root_transport.base)
 
     _gitrepository_class = property(_get_gitrepository_class)
@@ -616,9 +597,7 @@ class LocalGitDir(GitDir):
         return None
 
     def find_branch_format(self, name=None):
-        from .branch import (
-            LocalGitBranchFormat,
-            )
+        from .branch import LocalGitBranchFormat
         return LocalGitBranchFormat()
 
     def get_branch_transport(self, branch_format, name=None):
