@@ -20,42 +20,18 @@ import os
 import shutil
 import stat
 
-from dulwich.objects import (
-    Blob,
-    Tree,
-    )
+from dulwich.objects import Blob, Tree
 
-from ...branchbuilder import (
-    BranchBuilder,
-    )
-from ...bzr.inventory import (
-    InventoryDirectory,
-    InventoryFile,
-    )
-from ...errors import (
-    NoSuchRevision,
-    )
-from ...graph import (
-    DictParentsProvider,
-    Graph,
-    )
-from ...tests import (
-    TestCase,
-    TestCaseWithTransport,
-    )
+from ...branchbuilder import BranchBuilder
+from ...bzr.inventory import InventoryDirectory, InventoryFile
+from ...errors import NoSuchRevision
+from ...graph import DictParentsProvider, Graph
+from ...tests import TestCase, TestCaseWithTransport
 from ...tests.features import SymlinkFeature
-
-from ..cache import (
-    DictGitShaMap,
-    )
-from ..object_store import (
-    BazaarObjectStore,
-    LRUTreeCache,
-    directory_to_tree,
-    _check_expected_sha,
-    _find_missing_bzr_revids,
-    _tree_to_objects,
-    )
+from ..cache import DictGitShaMap
+from ..object_store import (BazaarObjectStore, LRUTreeCache,
+                            _check_expected_sha, _find_missing_bzr_revids,
+                            _tree_to_objects, directory_to_tree)
 
 
 class ExpectedShaTests(TestCase):
