@@ -15,51 +15,31 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
 import errno
 import os
 import posixpath
-from stat import S_IEXEC, S_ISREG
 import tempfile
 import time
+from stat import S_IEXEC, S_ISREG
 
-from .mapping import encode_git_path, mode_kind, mode_is_executable, object_mode
-from .tree import GitTree, GitTreeDirectory, GitTreeSymlink, GitTreeFile
-from .mapping import decode_git_path
+from dulwich.index import blob_from_path_and_stat, commit_tree
+from dulwich.objects import Blob
 
-from .. import (
-    annotate,
-    conflicts,
-    errors,
-    multiparent,
-    osutils,
-    revision as _mod_revision,
-    trace,
-    transport as _mod_transport,
-    ui,
-    urlutils,
-    )
+from .. import annotate, conflicts, errors, multiparent, osutils
+from .. import revision as _mod_revision
+from .. import trace
+from .. import transport as _mod_transport
+from .. import ui, urlutils
 from ..i18n import gettext
 from ..mutabletree import MutableTree
+from ..transform import (ROOT_PARENT, FinalPaths, ImmortalLimbo,
+                         MalformedTransform, PreviewTree, ReusingTransform,
+                         TransformRenameFailed, TreeTransform, _FileMover,
+                         _TransformResults, joinpath, unique_add)
 from ..tree import InterTree, TreeChange
-from ..transform import (
-    PreviewTree,
-    TreeTransform,
-    _TransformResults,
-    _FileMover,
-    FinalPaths,
-    joinpath,
-    unique_add,
-    TransformRenameFailed,
-    ImmortalLimbo,
-    ROOT_PARENT,
-    ReusingTransform,
-    MalformedTransform,
-    )
-
-from dulwich.index import commit_tree, blob_from_path_and_stat
-from dulwich.objects import Blob
+from .mapping import (decode_git_path, encode_git_path, mode_is_executable,
+                      mode_kind, object_mode)
+from .tree import GitTree, GitTreeDirectory, GitTreeFile, GitTreeSymlink
 
 
 class TreeTransformBase(TreeTransform):
@@ -74,7 +54,7 @@ class TreeTransformBase(TreeTransform):
         :param case_sensitive: If True, the target of the transform is
             case sensitive, not just case preserving.
         """
-        super(TreeTransformBase, self).__init__(tree, pb=pb)
+        super().__init__(tree, pb=pb)
         # mapping of trans_id => (sha1 of content, stat_value)
         self._observed_sha1s = {}
         # Set of versioned trans ids
@@ -756,17 +736,16 @@ class TreeTransformBase(TreeTransform):
         if not raw_conflicts:
             return
         fp = FinalPaths(self)
-        from .workingtree import TextConflict
+        from .workingtree import ContentsConflict, TextConflict
         for c in raw_conflicts:
             if c[0] == 'text conflict':
                 yield TextConflict(fp.get_path(c[1]))
+            elif c[0] == 'contents conflict':
+                yield ContentsConflict(fp.get_path(c[1][0]))
             elif c[0] == 'duplicate':
                 yield TextConflict(fp.get_path(c[2]))
-            elif c[0] == 'contents conflict':
-                yield TextConflict(fp.get_path(c[1][0]))
             elif c[0] == 'missing parent':
-                # TODO(jelmer): This should not make it to here
-                yield TextConflict(fp.get_path(c[2]))
+                pass
             elif c[0] == 'non-directory parent':
                 yield TextConflict(fp.get_path(c[2]))
             elif c[0] == 'deleting parent':
@@ -775,8 +754,6 @@ class TreeTransformBase(TreeTransform):
             elif c[0] == 'parent loop':
                 # TODO(jelmer): This should not make it to here
                 yield TextConflict(fp.get_path(c[2]))
-            elif c[0] == 'path conflict':
-                yield TextConflict(fp.get_path(c[1]))
             else:
                 raise AssertionError('unknown conflict %s' % c[0])
 
@@ -868,7 +845,7 @@ class DiskTreeTransform(TreeTransformBase):
     def adjust_path(self, name, parent, trans_id):
         previous_parent = self._new_parent.get(trans_id)
         previous_name = self._new_name.get(trans_id)
-        super(DiskTreeTransform, self).adjust_path(name, parent, trans_id)
+        super().adjust_path(name, parent, trans_id)
         if (trans_id in self._limbo_files
                 and trans_id not in self._needs_rename):
             self._rename_in_limbo([trans_id])
@@ -989,7 +966,7 @@ class DiskTreeTransform(TreeTransformBase):
             except KeyError:
                 path = None
             trace.warning(
-                'Unable to create symlink "%s" on this filesystem.' % (path,))
+                'Unable to create symlink "{}" on this filesystem.'.format(path))
             self._symlink_target[trans_id] = target
         # We add symlink to _new_contents even if they are unsupported
         # and not created. These entries are subsequently used to avoid
@@ -1268,10 +1245,7 @@ class GitTreeTransform(DiskTreeTransform):
             return
         try:
             children = os.listdir(self._tree.abspath(path))
-        except OSError as e:
-            if not (osutils._is_error_enotdir(e) or
-                    e.errno in (errno.ENOENT, errno.ESRCH)):
-                raise
+        except (NotADirectoryError, FileNotFoundError):
             return
 
         for child in children:
@@ -1701,8 +1675,8 @@ class GitPreviewTree(PreviewTree, GitTree):
         return osutils.split_lines(self.get_file_text(path))
 
     def extras(self):
-        possible_extras = set(self._transform.trans_id_tree_path(p) for p
-                              in self._transform._tree.extras())
+        possible_extras = {self._transform.trans_id_tree_path(p) for p
+                              in self._transform._tree.extras()}
         possible_extras.update(self._transform._new_contents)
         possible_extras.update(self._transform._removed_id)
         for trans_id in possible_extras:
