@@ -18,13 +18,11 @@ __docformat__ = "google"
 
 """Support for plugin hooking logic."""
 
-from typing import Dict, Tuple, List
+from typing import Dict, List, Tuple
 
-from . import (
-    errors,
-    registry,
-    )
+from . import errors, registry
 from .lazy_import import lazy_import
+
 lazy_import(globals(), """
 from breezy import (
     _format_version_tuple,
@@ -44,7 +42,7 @@ class UnknownHook(errors.BzrError):
         self.hook = hook_name
 
 
-class KnownHooksRegistry(registry.Registry):
+class KnownHooksRegistry(registry.Registry[str, "Hooks"]):
     # known_hooks registry contains
     # tuple of (module, member name) which is the hook point
     # module where the specific hooks are defined
@@ -168,17 +166,7 @@ class Hooks(dict):
         hook_docs.append("")
         for hook_name in hook_names:
             hook = self[hook_name]
-            try:
-                hook_docs.append(hook.docs())
-            except AttributeError:
-                # legacy hook
-                strings = []
-                strings.append(hook_name)
-                strings.append("~" * len(hook_name))
-                strings.append("")
-                strings.append("An old-style hook. For documentation see the __init__ "
-                               "method of '%s'\n" % (name,))
-                hook_docs.extend(strings)
+            hook_docs.append(hook.docs())
         return "\n".join(hook_docs)
 
     def get_hook_name(self, a_callable):
@@ -273,7 +261,7 @@ class Hooks(dict):
             callable_name
 
 
-class HookPoint(object):
+class HookPoint:
     """A single hook that clients can register to be called back when it fires.
 
     Attributes:
