@@ -17,38 +17,19 @@
 
 
 import time
-from .... import (
-    debug,
-    delta,
-    errors,
-    osutils,
-    progress,
-    revision as _mod_revision,
-    )
-from ....bzr.knitpack_repo import KnitPackRepository
-from ....trace import (
-    mutter,
-    note,
-    warning,
-    )
-import configobj
-from .. import (
-    branch_updater,
-    cache_manager,
-    helpers,
-    idmapfile,
-    marks_file,
-    revision_store,
-    )
-from fastimport import (
-    commands,
-    errors as plugin_errors,
-    processor,
-    )
-from fastimport.helpers import (
-    invert_dictset,
-    )
 
+import configobj
+from fastimport import commands
+from fastimport import errors as plugin_errors
+from fastimport import processor
+from fastimport.helpers import invert_dictset
+
+from .... import debug, delta, errors, osutils, progress
+from .... import revision as _mod_revision
+from ....bzr.knitpack_repo import KnitPackRepository
+from ....trace import mutter, note, warning
+from .. import (branch_updater, cache_manager, helpers, idmapfile, marks_file,
+                revision_store)
 
 # How many commits before automatically reporting progress
 _DEFAULT_AUTO_PROGRESS = 1000
@@ -200,6 +181,7 @@ class GenericProcessor(processor.ImportProcessor):
 
     def _load_info_and_params(self):
         from .. import bzr_commit_handler
+
         # This is currently hard-coded but might be configurable via
         # parameters one day if that's needed
         repo_transport = self.repo.control_transport
@@ -274,7 +256,7 @@ class GenericProcessor(processor.ImportProcessor):
         elif self.repo is not None:
             self.repo.lock_write()
         try:
-            super(GenericProcessor, self)._process(command_iter)
+            super()._process(command_iter)
         finally:
             # If an unhandled exception occurred, abort the write group
             if self.repo is not None and self.repo.is_in_write_group():
@@ -546,7 +528,7 @@ class GenericProcessor(processor.ImportProcessor):
         # Most progress messages embedded in streams are annoying.
         # Ignore them unless in verbose mode.
         if self.verbose:
-            self.note("progress %s" % (cmd.message,))
+            self.note("progress {}".format(cmd.message))
 
     def reset_handler(self, cmd):
         """Process a ResetCommand."""
@@ -584,15 +566,15 @@ class GenericProcessor(processor.ImportProcessor):
     def debug(self, msg, *args):
         """Output a debug message if the appropriate -D option was given."""
         if "fast-import" in debug.debug_flags:
-            msg = "%s DEBUG: %s" % (self._time_of_day(), msg)
+            msg = "{} DEBUG: {}".format(self._time_of_day(), msg)
             mutter(msg, *args)
 
     def note(self, msg, *args):
         """Output a note but timestamp it."""
-        msg = "%s %s" % (self._time_of_day(), msg)
+        msg = "{} {}".format(self._time_of_day(), msg)
         note(msg, *args)
 
     def warning(self, msg, *args):
         """Output a warning but timestamp it."""
-        msg = "%s WARNING: %s" % (self._time_of_day(), msg)
+        msg = "{} WARNING: {}".format(self._time_of_day(), msg)
         warning(msg, *args)
