@@ -19,32 +19,18 @@
 
 import signal
 import sys
+import threading
 from _thread import interrupt_main  # type: ignore
 
-import threading
-
-from ... import (
-    builtins,
-    config,
-    errors,
-    osutils,
-    revision as _mod_revision,
-    trace,
-    transport,
-    urlutils,
-    )
+from ... import builtins, config, errors, osutils
+from ... import revision as _mod_revision
+from ... import trace, transport, urlutils
 from ...branch import Branch
-from ...controldir import ControlDir
 from ...bzr.smart import client, medium
-from ...bzr.smart.server import (
-    BzrServerFactory,
-    SmartTCPServer,
-    )
-from .. import (
-    TestCaseWithMemoryTransport,
-    TestCaseWithTransport,
-    )
+from ...bzr.smart.server import BzrServerFactory, SmartTCPServer
+from ...controldir import ControlDir
 from ...transport import remote
+from .. import TestCaseWithMemoryTransport, TestCaseWithTransport
 
 
 class TestBzrServeBase(TestCaseWithTransport):
@@ -106,7 +92,7 @@ class TestBzrServeBase(TestCaseWithTransport):
 class TestBzrServe(TestBzrServeBase):
 
     def setUp(self):
-        super(TestBzrServe, self).setUp()
+        super().setUp()
         self.disable_missing_extensions_warning()
 
     def test_server_exception_with_hook(self):
