@@ -19,13 +19,8 @@
 import shutil
 
 from breezy import errors
+from breezy.tests import TestNotApplicable, TestSkipped, features, per_tree
 from breezy.tree import MissingNestedTree
-from breezy.tests import per_tree
-from breezy.tests import (
-    TestNotApplicable,
-    TestSkipped,
-    features,
-    )
 
 
 class TestTreeShapes(per_tree.TestCaseWithTree):
