@@ -910,10 +910,14 @@ class TestTreeTransform(TestCaseWithWorkingTree):
             self.assertEqual(cooked_conflicts[5], unversioned_parent2)
             self.assertEqual(cooked_conflicts[6], parent_loop)
             self.assertEqual(len(cooked_conflicts), 7)
-        else:
+        elif self.wt.has_versioned_directories():
             self.assertEqual(
                 {c.path for c in cooked_conflicts},
                 {'oz/emeraldcity', 'oz', 'munchkincity', 'dorothy.moved'})
+        else:
+            self.assertEqual(
+                {c.path for c in cooked_conflicts},
+                {'oz/emeraldcity', 'oz', 'dorothy.moved'})
         tt.finalize()
 
     def test_string_conflicts(self):
@@ -943,13 +947,19 @@ class TestTreeTransform(TestCaseWithWorkingTree):
                                              ' children.  Versioned directory.')
             self.assertEqual(conflicts_s[6], 'Conflict moving oz/emeraldcity into'
                                              ' oz/emeraldcity. Cancelled move.')
-        else:
+        elif self.wt.has_versioned_directories():
             self.assertEqual(
                 {'Text conflict in dorothy.moved',
                  'Text conflict in munchkincity',
                  'Text conflict in oz',
                  'Text conflict in oz/emeraldcity'},
                 {c for c in conflicts_s})
+        else:
+            self.assertEqual(
+                {'Text conflict in dorothy.moved',
+                 'Text conflict in oz',
+                 'Text conflict in oz/emeraldcity'},
+                {c for c in conflicts_s})
 
     def prepare_wrong_parent_kind(self):
         tt, root = self.transform()
