@@ -17,23 +17,10 @@
 import os
 from typing import List
 
-from ..forge import (
-    determine_title,
-    get_proposal_by_url,
-    get_forge,
-    Forge,
-    MergeProposal,
-    UnsupportedForge,
-    )
-from .. import (
-    forge as _mod_forge,
-    registry,
-    urlutils,
-    )
-
-from .. import (
-    tests,
-    )
+from .. import forge as _mod_forge
+from .. import registry, tests, urlutils
+from ..forge import (Forge, MergeProposal, UnsupportedForge, determine_title,
+                     get_forge, get_proposal_by_url)
 
 
 class SampleMergeProposal(MergeProposal):
@@ -75,7 +62,7 @@ class SampleForge(Forge):
 class SampleForgeTestCase(tests.TestCaseWithTransport):
 
     def setUp(self):
-        super(SampleForgeTestCase, self).setUp()
+        super().setUp()
         self._old_forges = _mod_forge.forges
         _mod_forge.forges = registry.Registry()
         self.forge = SampleForge()
@@ -85,7 +72,7 @@ class SampleForgeTestCase(tests.TestCaseWithTransport):
         _mod_forge.forges.register('sample', self.forge)
 
     def tearDown(self):
-        super(SampleForgeTestCase, self).tearDown()
+        super().tearDown()
         _mod_forge.forges = self._old_forges
         SampleForge._locations = []
 
